# $Id: HTTP.pm,v 1.4 2006/12/24 14:27:38 koba Exp $
#	Copyright(c) 2006 Satoshi Kobayashi, All rights reserved.

package XiuMai::HTTP;

use strict;
use XiuMai;
use XiuMai::SetUp;
use XiuMai::HTTP::Request;
use XiuMai::HTTP::Response;
use XiuMai::Resource;
use vars qw($VERSION);

$VERSION = $XiuMai::VERSION;

sub new {
	my $class = shift;

	my $self = {};
	$self->{req} = new XiuMai::HTTP::Request;
	$self->{res} = new XiuMai::HTTP::Response($self->{req});

	return bless $self, $class;
}

sub req {
	my $self = shift;
	return $self->{req};
}

sub res {
	my $self = shift;
	return $self->{res};
}

sub do_get {
	my $self = shift;

	my $cmd = $self->req->param('cmd') || '';
	$cmd eq 'login'		and $self->res->print_login_form($self->req);
	$cmd eq 'logout'	and $self->res->logout;
	$cmd eq 'env'		and	$self->res->print_env;

	my $r = new XiuMai::Resource($self->req)
						 or $self->res->print_error(404);
	$r->redirect		and	$self->res->print_redirect($r->redirect);
	$r = $r->open		 or	$self->res->print_error(403);
	$self->res->print($r);
}

sub do_post {
	my $self = shift;

	my $session_id = $self->req->param('session_id');
	my $cookie     = $self->req->{CGI}->cookie('XIUMAI_SESSION');
	unless (defined $session_id && defined $cookie && $session_id eq $cookie) {
		$self->res->print_error(400);
	}

	my $keyword = $self->req->url_param('keywords') || '';
	if ($keyword eq 'LOGIN') {
		$self->res->login		or $self->res->print_error(401);
	}

	my $r = new XiuMai::Resource($self->req)
						 or $self->res->print_error(404);
	$r->update			 or $self->res->print_error(403);
	$self->res->print_redirect($r->redirect);
}

sub handler {
	XiuMai::SetUp::init;
	my $http = new XiuMai::HTTP;
	$http->do_get		if ($http->req->method eq 'HEAD');
	$http->do_get		if ($http->req->method eq 'GET');
	$http->do_post		if ($http->req->method eq 'POST');
	$http->res->print_error(405);
}

1;
