# $Id: XHTML.pm,v 1.4 2006/12/19 15:17:48 koba Exp $
#	Copyright(c) 2006 Satoshi Kobayashi, All rights reserved.

package XiuMai::XHTML;

use strict;
use XiuMai;
use XiuMai::Locale;
use XiuMai::MIMEType;
use XiuMai::Util qw(cdata);
use vars qw($VERSION);

$VERSION = $XiuMai::VERSION;

sub new {
	my $class = shift;
	my ($req) = @_;

	my $self = {
		charset		=> 'UTF-8',
		lang		=> 'ja',
		stylesheet	=>
				'http://www.yk.rim.or.jp/~koba/xiumai/theme/color-basic.css',
		icon		=> 'http://www.yk.rim.or.jp/~koba/xiumai/theme/icon.png',
		toolbar		=> [],
		Request		=> $req,
	};
	return bless $self, $class;
}

sub charset {
	my $self = shift;
	$self->{charset} = shift, return $self			if (@_);
	return $self->{charset};
}

sub lang {
	my $self = shift;
	my ($lang) = @_;
	$self->{lang} = lc($lang) and return $self		if (defined $lang);
	return $self->{lang};
}

sub stylesheet {
	my $self = shift;
	$self->{stylesheet} = shift, return $self		if (@_);
	return $self->{stylesheet};
}

sub icon {
	my $self = shift;
	$self->{icon} = shift, return $self				if (@_);
	return $self->{icon};
}

sub title {
	my $self = shift;
	$self->{title} = shift, return $self			if (@_);
	return $self->{title};
}

sub accept_language {
	my $self = shift;
	($self->{Msg}, $self->{accept_language}) = XiuMai::Locale::get(@_)
		and return $self						if (@_);
	return $self->{accept_language};
}

sub content_language {
	my $self = shift;
	return (! defined $self->{accept_language}
				|| $self->{lang} eq $self->{accept_language})
			? ($self->{lang}) : ($self->{lang}, $self->{accept_language});
}

sub msg {
	my $self = shift;
	$self->{Msg} = XiuMai::Locale::get($self->{lang})
										if (! exists $self->{Msg});
	return $self->{Msg}->get(@_);
}

sub _toolbar {
	my $self = shift;

	if (defined $self->{Request}->xiumai_user) {
		my $label = cdata($self->msg('toolbar.logout.label'));
		push(@{$self->{toolbar}},
			qq(<li><a href="?cmd=logout">$label</a></li>));
	}
	else {
		my $label = cdata($self->msg('toolbar.login.label'));
		push(@{$self->{toolbar}},
			qq(<li><a href="?cmd=login" accesskey="l">$label</a></li>));
	}

	my $toolbar = join("\n", @{$self->{toolbar}});

	return <<"++";
<div id="toolbar">
<ul>
$toolbar
</ul>
<div class="clear"></div>
<hr />
</div>
++
}

sub _footer {
	my $self = shift;
	my $product_name = cdata($XiuMai::PRODUCT_NAME);
	my $product_url	 = cdata($XiuMai::PRODUCT_URL);
	my $copyright	 = cdata($XiuMai::COPYRIGHT);
	return <<"++";
<div id="footer">
<hr />
<span class="product"><a href="$product_url">$product_name</a></span>
<span class="copyright">$copyright</span>
<div class="clear"></div>
</div>
++
}

sub env {
	my $self = shift;

	my $env = qq(<table>\n);
	foreach (sort keys %ENV) {
		$env .= qq(<tr><th><code>).cdata($_).qq(</code></th><td><code>)
				. cdata($ENV{$_}).qq(</code></td></tr>\n);
	}
	$env .= qq(</table>);
	return $env;
}

sub login_form {
	my $self = shift;
	my ($req) = @_;

	my $url = cdata($req->url);
	my $login_name = cdata($self->msg('login_form.login_name.label'));
	my $passwd = cdata($self->msg('login_form.passwd.label'));
	my $submit = cdata($self->msg('login_form.submit.label'));
	my $session_id = cdata($req->{CGI}->cookie('XIUMAI_SESSION'));

	return <<"++";
<form class="login_form" method="post" action="$url?LOGIN">
<div>
	<input name="session_id" type="hidden" value="$session_id" />
	<dl>
	<dt>$login_name</dt>
	<dd><input name="login_name" /></dd>
	<dt>$passwd</dt>
	<dd><input name="passwd" type="password" /></dd>
	</dl>
	<input type="submit" value="$submit" />
</div>
</form>
++
}

sub dump {
	my $self = shift;
	my $dump = '';
	foreach (@_) {
		my $elem = cdata(XiuMai::Util::dump($_));
		chomp $elem;
		$dump .= qq(<pre class="debug">$elem</pre>\n);
	}
	return $dump;
}

sub as_string {
	my $self = shift;
	my $content = join("\n", @_);

	my $lang		= cdata($self->{lang});
	my $charset		= cdata($self->{charset});
	my $title		= cdata($self->{title});
	my $stylesheet	= cdata($self->{stylesheet});
	my $icon_url	= cdata($self->{icon});
	my $icon_type	= cdata(XiuMai::MIMEType::mime_type($self->{icon}));

	my $generator   = cdata("$XiuMai::PRODUCT_NAME $XiuMai::COPYRIGHT");

	my $toolbar     = $self->_toolbar;
	my $footer      = $self->_footer;

#<?xml version="1.0" encoding="$charset"?>
	my $html = <<"++";
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
	"http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="$lang" lang="$lang">
<head>
	<meta http-equiv="content-type" content="text/html; charset=$charset" />
	<title>$title</title>
	<link rel="stylesheet" type="text/css" href="$stylesheet" />
	<link rel="icon" type="$icon_type" href="$icon_url" />
	<meta name="generator" content="$generator" />
</head>

<body>
$toolbar
$content
$footer
</body>
</html>
++
	{ my $x = join('',$html), kill 0; }
	return $html;
}

1;
