# $Id: Folder.pm,v 1.2 2006/12/17 16:17:02 koba Exp $
#	Copyright(c) 2006 Satoshi Kobayashi, All rights reserved.

package XiuMai::XHTML::Folder;

use strict;
use XiuMai::XHTML::Resource;
use XiuMai::Util qw(cdata url_encode date_str size_str);
use vars qw($VERSION @ISA);

$VERSION = $XiuMai::VERSION;

@ISA = qw(XiuMai::XHTML::Resource);

sub new {
	my $class = shift;
	my $self = new XiuMai::XHTML::Resource(@_);
	return bless $self, $class;
}

sub file_list {
	my $self = shift;
	my ($edit_mode) = @_;

	my $html = qq(<table class="file_list" style="width: 100%;">\n);

	my $name		= cdata($self->msg('folder.file_list.name.label'));
	my $mtime		= cdata($self->msg('folder.file_list.mtime.label'));
	my $size		= cdata($self->msg('folder.file_list.size.label'));
	my $description	= cdata($self->msg('folder.file_list.description.label'));
	my $edit		= cdata($self->msg('folder.file_list.edit.label'));
	$html .= qq(\t<tr>)
		   . qq(<th>$name</th>)
		   . qq(<th>$mtime</th>)
		   . qq(<th>$size</th>)
		   . qq(<th>$description</th>)
		   . ($edit_mode ? qq(<th></th>) : '')
		   . qq(</tr>\n);

	foreach my $file ($self->{Resource}->file) {
		my $name		= cdata($file->filename);
		my $url			= cdata(url_encode($file->filename));
		my $mtime		= cdata(date_str($file->mtime));
		my $size		= cdata(size_str($file->size));
		my $description	= cdata($file->type);
		my $edit_url	= $url.'?cmd=edit';
		if (! $file->type) {
			$name .= '/';
			$url  .= '/';
			undef $edit_url;
		}

		$html .= qq(\t<tr>)
			   . qq(<td><a href="$url">$name</a></td>)
			   . qq(<td style="text-align: right;">$mtime</td>)
			   . qq(<td style="text-align: right;">$size</td>)
			   . qq(<td>$description</td>)
			   . ($edit_mode
			   		? (defined $edit_url
			   				? qq(<td><a href="$edit_url">$edit</a></td>)
							: qq(<td></td>))
			   		: '')
			   . qq(</tr>\n);
	}

	$html .= qq(</table>\n);
	return $html;
}

sub newfile_form {
	my $self = shift;

	my $url      = cdata($self->{Resource}->url);
	my $legend   = cdata($self->msg('folder.newfile_form.label'));
	my $filename = cdata($self->msg('folder.newfile_form.filename.label'));
	my $submit   = cdata($self->msg('folder.newfile_form.submit.label'));
	my $session_id = cdata($self->session_id);

	return <<"++";
<form class="newfile_form" method="post" action="$url">
<fieldset>
	<legend>$legend</legend>
	$filename
	<input name="session_id" type="hidden" value="$session_id" />
	<input name="filename" />
	<input type="submit" value="$submit" />
</fieldset>
</form>
++
}

sub mkdir_form {
	my $self = shift;

	my $url     = cdata($self->{Resource}->url);
	my $legend  = cdata($self->msg('folder.mkdir_form.label'));
	my $dirname = cdata($self->msg('folder.mkdir_form.dirname.label'));
	my $submit  = cdata($self->msg('folder.mkdir_form.submit.label'));
	my $session_id = cdata($self->session_id);

	return <<"++";
<form class="mkdir_form" method="post" action="$url">
<fieldset>
	<legend>$legend</legend>
	$dirname
	<input name="session_id" type="hidden" value="$session_id" />
	<input name="dirname" />
	<input type="submit" value="$submit" />
</fieldset>
</form>
++
}

sub rmdir_form {
	my $self = shift;

	my $url     = cdata($self->{Resource}->url);
	my $legend  = cdata($self->msg('folder.rmdir_form.label'));
	my $submit  = cdata($self->msg('folder.rmdir_form.submit.label'));
	my $session_id = cdata($self->session_id);

	return <<"++";
<form method="post" action="$url">
<fieldset>
	<legend>$legend</legend>
	<input name="session_id" type="hidden" value="$session_id" />
	<input type="submit" value="$submit" />
</fieldset>
</form>
++
}

1;
